@@ -6,15 +6,6 @@ from configparser import ConfigParser
 from mergeconf import exceptions
 from mergeconf.mergeconfsection import MergeConfSection
 
-# deprecation apology message
-deprecation_msg = """
-This method is deprecated immediately.  I apologise for any inconvenience, but
-I estimate uptake of this library to be in the low 1's and probably actually
-just 1.  To continue using the API you're expecting, you can specify version
-0.3 of the library but it was overhauled for better functionality and, I think,
-a nicer API.
-"""
-
 
 class MergeConf(MergeConfSection):
   """
@@ -54,6 +45,7 @@ class MergeConf(MergeConfSection):
     """
     super().__init__(None, map=map)
 
+    self._args = None
     self._codename = codename
     self._strict = strict
 
@@ -73,13 +65,23 @@ class MergeConf(MergeConfSection):
         "be removed.  Please use `add()` to add configuration options and " \
         "their specifications, including default values.")
 
+  # overload this here in order to try and catch non-mergeconf CLI arguments
+  # if appropriate
+  def __getattr__(self, attr):
+    try:
+      return super().__getattr__(attr)
+    except AttributeError as e:
+      if self._args is not None and attr in vars(self._args):
+        return vars(self._args)[attr]
+      raise e
+
   def map(self, fn):
     """
     Apply the given function to every item in this section and recursively for
     subsections.
 
     Args:
-      fn: Function taking (sections, name, MergeConfValue) and returning some
+      fn: Function taking (sections, name, MergeConfItem) and returning some
         value, or None.
 
     Returns:
@@ -142,6 +144,9 @@ class MergeConf(MergeConfSection):
 
     self.map(grokarg)
 
+    # retain args for retrieving individual non-mergeconf CLI args
+    self._args = args
+
   def merge_environment(self):
     """
     Using configuration definition, reads in variables from the environment
@@ -299,29 +304,3 @@ class MergeConf(MergeConfSection):
     # extra empty string.  Get rid of this before joining all the lines
     # together with a newline to build the "file".
     return '\n'.join(self._sample_config()[:-1])
-
-  # -------------------------------------------------------------------------
-  #                                                       deprecated methods
-  # -------------------------------------------------------------------------
-
-  # pylint: disable=no-self-use
-  def add_boolean(self, key, value=None, mandatory=False):
-    """
-    _Deprecated._  Add a configuration item of type Boolean.
-
-    Args:
-      key (str): Name of configuration item
-      value (boolean): Default value, None by default
-      mandatory (boolean): Whether item is mandatory or not, defaults to
-        False.
-
-    Note: This is deprecated; simply use `add` with `type=bool`.
-    """
-    raise exceptions.Deprecated(version='0.3', message=deprecation_msg)
-
-  # pylint: disable=no-self-use
-  def parse(self, *args, **kwargs):
-    """
-    Deprecated.  See merge().
-    """
-    raise exceptions.Deprecated(version='0.3', message=deprecation_msg)
